@@ -127,6 +127,8 @@ void FileLVI::setText( int column, const QString &text )
 		QString name = text;
 		if ( name.endsWith( "/" ) )
 			name = name.left( name.length() - 1 );
+		if ( name.startsWith( "/" ) )
+			name = name.mid( 1 );
 		int pos = name.findRev( '/' );
 		if ( pos != -1 )
 			name = name.right( name.length() - pos - 1 );
@@ -135,12 +137,12 @@ void FileLVI::setText( int column, const QString &text )
 	}
 	else if ( colName == sizeCol )
 	{
-		m_fileSize = text.toLong();
+		m_fileSize = text.toULongLong();
 		QListViewItem::setText( column, KIO::convertSize( m_fileSize ) );
 	}
 	else if ( colName == packedStrCol )
 	{
-		m_packedFileSize = text.toLong();
+		m_packedFileSize = text.toULongLong();
 		QListViewItem::setText( column, KIO::convertSize( m_packedFileSize ) );
 	}
 	else if ( colName == ratioStrCol )
@@ -156,8 +158,13 @@ void FileLVI::setText( int column, const QString &text )
 	}
 	else if ( colName == timeStampStrCol )
 	{
-		m_timeStamp = QDateTime::fromString( text, ISODate );
-		QListViewItem::setText( column, KGlobal::locale()->formatDateTime( m_timeStamp ) );
+		if ( text.isEmpty() )
+			QListViewItem::setText(column, text);
+		else
+		{
+			m_timeStamp = QDateTime::fromString( text, ISODate );
+			QListViewItem::setText( column, KGlobal::locale()->formatDateTime( m_timeStamp ) );
+		}
 	}
 	else
 		QListViewItem::setText(column, text);
@@ -166,8 +173,11 @@ void FileLVI::setText( int column, const QString &text )
 static FileLVI* folderLVI( KListViewItem *parent, const QString& name )
 {
 	FileLVI *folder = new FileLVI( parent );
+
 	folder->setText( 0, name );
+
 	folder->setPixmap( 0, KMimeType::mimeType( "inode/directory" )->pixmap( KIcon::Small ) );
+
 	return folder;
 }
 
@@ -193,7 +203,6 @@ FileListView::FileListView(QWidget *parent, const char* name)
 
 	setMultiSelection( true );
 	setSelectionModeExt( FileManager );
-	setDragEnabled( true );
 	setItemsMovable( false );
 	setRootIsDecorated( true );
 	setShowSortIndicator( true );
@@ -497,6 +506,8 @@ FileLVI* FileListView::findParent( const QString& fullname )
 
 	if ( name.endsWith( "/" ) )
 		name = name.left( name.length() -1 );
+	if ( name.startsWith( "/" ) )
+		name = name.mid( 1 );
 	// Checks if this entry needs a parent
 	if ( !name.contains( '/' ) )
 		return static_cast< FileLVI* >( 0 );
