@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -75,6 +75,7 @@ void KCalcButton::slotSetMode(ButtonModeFlags mode, bool flag)
       _label = _mode[new_mode].label;
     else
       setText(_mode[new_mode].label);
+	QToolTip::remove(this);
     QToolTip::add(this, _mode[new_mode].tooltip);
     _mode_flags = new_mode;
 
