@@ -63,7 +63,8 @@ class _knumber
 
   virtual int compare(_knumber const &arg2) const = 0;
 
-  virtual operator long int (void) const = 0;
+  virtual operator signed long int (void) const = 0;
+  virtual operator unsigned long int (void) const = 0;
   virtual operator double (void) const = 0;
 };
 
@@ -106,7 +107,8 @@ class _knumerror : public _knumber
 
   virtual int compare(_knumber const &arg2) const;
 
-  virtual operator long int (void) const;
+  virtual operator signed long int (void) const;
+  virtual operator unsigned long int (void) const;
   virtual operator double (void) const;
 
  private:
@@ -132,12 +134,19 @@ class _knuminteger : public _knumber
   {
     mpz_init_set_ui(_mpz, num);
   }
-  
+
   _knuminteger(signed long int num)
   {
     mpz_init_set_si(_mpz, num);
   }
 
+  _knuminteger(unsigned long int num)
+  {
+    mpz_init_set_ui(_mpz, num);
+  }
+  
+  _knuminteger(unsigned long long int num);
+
   _knuminteger(_knumber const & num);
 
   _knuminteger(const QString & num);
@@ -172,7 +181,8 @@ class _knuminteger : public _knumber
 
   virtual _knumber * power(_knumber const & exponent) const;
 
-  virtual operator long int (void) const;
+  virtual operator signed long int (void) const;
+  virtual operator unsigned long int (void) const;
   virtual operator double (void) const;
 
   _knuminteger * intAnd(_knuminteger const &arg2) const;
@@ -234,7 +244,8 @@ class _knumfraction : public _knumber
   
   virtual int compare(_knumber const &arg2) const;
 
-  virtual operator long int (void) const;
+  virtual operator signed long int (void) const;
+  virtual operator unsigned long int (void) const;
   virtual operator double (void) const;
 
  private:
@@ -286,7 +297,8 @@ class _knumfloat : public _knumber
 
   virtual int compare(_knumber const &arg2) const;
 
-  virtual operator long int (void) const;
+  virtual operator signed long int (void) const;
+  virtual operator unsigned long int (void) const;
   virtual operator double (void) const;
 
  private:
