@@ -1,3 +1,31 @@
+/*
+**
+** Copyright (C) 1998 by Michael Kropfberger
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
+
 #include <kapplication.h>
 #include <kconfig.h>
 
@@ -21,7 +49,7 @@ void CStdOption::updateConfiguration( void )
 {
   KConfig &config = *kapp->config();
   config.setGroup("KDFConfig");
-  mFileManager = config.readEntry(
+  mFileManager = config.readPathEntry(
     "FileManagerCommand", mDefaultFileManager );
   mUpdateFrequency = config.readNumEntry( 
     "UpdateFrequency", mDefaultUpdateFrequency );
@@ -37,7 +65,7 @@ void CStdOption::writeConfiguration( void )
   KConfig &config = *kapp->config();
   config.setGroup("KDFConfig");
   config.writeEntry( "UpdateFrequency", mUpdateFrequency );
-  config.writeEntry( "FileManagerCommand", mFileManager );
+  config.writePathEntry( "FileManagerCommand", mFileManager );
   config.writeEntry( "PopupIfFull", mPopupIfFull );
   config.writeEntry( "OpenFileMgrOnMount", mOpenFileManagerOnMount );
   config.sync();
@@ -48,7 +76,7 @@ void CStdOption::writeDefaultFileManager( void )
 {
   KConfig &config = *kapp->config();
   config.setGroup("KDFConfig");
-  config.writeEntry( "FileManagerCommand", mDefaultFileManager );
+  config.writePathEntry( "FileManagerCommand", mDefaultFileManager );
   config.sync();
 }
 
