@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -50,7 +50,6 @@ const QString &hexError( int index )
     i18n("Program is busy, try again later"),           // Err_Busy
     i18n("Value is not within valid range"),            // Err_IllegalRange
     i18n("Operation was aborted"),                      // Err_OperationAborted
-    i18n("KIO job in progress"),                        // Err_KioInProgress
     i18n("File could not be opened for writing"),       // Err_OpenWriteFailed
     i18n("File could not be opened for reading"),       // Err_OpenReadFailed
   }; 
