@@ -23,6 +23,7 @@
 #include <qfile.h>
 // lib specific
 #include "kdatabuffer.h"
+#include "khexedit_export.h"
 
 namespace KHE {
 
@@ -32,7 +33,7 @@ namespace KHE {
   *@author Friedrich W. H. Kossebau
   */
 
-class KBigBuffer : public KDataBuffer
+class KHEXEDIT_EXPORT KBigBuffer : public KDataBuffer
 {
     typedef QValueVector<char *> KPageOfChar;
 
@@ -44,15 +45,17 @@ class KBigBuffer : public KDataBuffer
   public: // KDataBuffer API
     virtual bool prepareRange( KSection Range ) const;
     virtual const char *dataSet( KSection S ) const;
-    virtual char datum( int Offset ) const;
+    virtual char datum( unsigned int Offset ) const;
     virtual int size() const;
     virtual bool isReadOnly() const;
     virtual bool isModified() const;
 
     virtual int insert( int Pos, const char*, int Length );
     virtual int remove( KSection S );
-    virtual int replace( KSection S, const char*, int InputLength );
+    virtual unsigned int replace( KSection S, const char*, unsigned int InputLength );
     virtual int move( int DestPos, KSection SourceSection );
+    virtual int fill( char FillChar, int Length = -1, unsigned int Pos = 0 );
+    virtual void setDatum( unsigned int Offset, const char Char );
 
     virtual void setModified( bool M = true );
 
@@ -69,8 +72,8 @@ class KBigBuffer : public KDataBuffer
     bool close();
 
   protected:
-    bool ensurePageLoaded( int PageIndex ) const;
-    bool freePage( int PageIndex ) const;
+    bool ensurePageLoaded( unsigned int PageIndex ) const;
+    bool freePage( unsigned int PageIndex ) const;
 
 
   protected:
@@ -81,11 +84,11 @@ class KBigBuffer : public KDataBuffer
     bool IsOpen:1;
     bool AtEOF:1;
     /** maximum number of pages which could be currently loaded */
-    int NoOfUsedPages;
+    unsigned int NoOfUsedPages;
     /**  number of actually not used pages (in terms of NoOfUsedPages) */
     mutable int NoOfFreePages;
     /** number of bytes in a page */
-    int PageSize;
+    unsigned int PageSize;
     /** first currently loaded page */
     mutable int FirstPage;
     /** last currently loaded page */
@@ -93,10 +96,10 @@ class KBigBuffer : public KDataBuffer
     /** */
     mutable KPageOfChar Data;
     /** */
-    int Size;
+    unsigned int Size;
 
     /** current offset */
-    mutable int OffsetOfActualPage;
+    mutable unsigned int OffsetOfActualPage;
     /** points to the actual page */
     mutable char* ActualPage;
 };
@@ -107,6 +110,8 @@ inline bool KBigBuffer::isModified() const   { return false; }
 inline void KBigBuffer::setReadOnly( bool RO ) { ReadOnly = RO; }
 inline void KBigBuffer::setModified( bool )  {}
 
+inline void KBigBuffer::setDatum( unsigned int, const char )  {}
+
 inline bool KBigBuffer::isOpen() const { return File.isOpen(); }
 
 }
