@@ -175,8 +175,9 @@ QChar KHexEdit::undefinedChar()                const { return charColumn().undef
 KHexEdit::KEncoding KHexEdit::encoding()       const { return (KHexEdit::KEncoding)Encoding; }
 const QString &KHexEdit::encodingName()        const { return Codec->name(); }
 
-int KHexEdit::cursorPosition() const { return BufferCursor->index(); }
-bool KHexEdit::isCursorBehind() const { return BufferCursor->isBehind(); }
+KSection KHexEdit::selection()                 const { return BufferRanges->selection(); }
+int KHexEdit::cursorPosition()                 const { return BufferCursor->index(); }
+bool KHexEdit::isCursorBehind()                const { return BufferCursor->isBehind(); }
 KHexEdit::KBufferColumnId KHexEdit::cursorColumn() const
 { return static_cast<KHE::KValueColumn *>( ActiveColumn ) == &valueColumn()? ValueColumnId : CharColumnId; }
 
@@ -745,16 +746,38 @@ bool KHexEdit::selectWord( /*unsigned TODO:change all unneeded signed into unsig
   return false;
 }
 
+void KHexEdit::select( KSection Section )
+{
+  if( !Section.isValid() )
+    return;
+
+  Section.restrictTo( KSection(0,BufferLayout->length()-1) );
+
+  pauseCursor();
+
+  BufferRanges->setSelection( Section );
+  BufferCursor->gotoIndex( Section.end()+1 );
+  repaintChanged();
+
+  unpauseCursor();
+
+  if( !OverWrite ) emit cutAvailable( BufferRanges->hasSelection() );
+  emit copyAvailable( BufferRanges->hasSelection() );
+  emit selectionChanged( Section.start(), Section.end() );
+}
 
 void KHexEdit::selectAll( bool Select )
 {
+  KSection Selection;
+
   pauseCursor( true );
 
   if( !Select )
     BufferRanges->removeSelection();
   else
   {
-    BufferRanges->setSelection( KSection(0,BufferLayout->length()-1) );
+    Selection.set( 0, BufferLayout->length()-1 );
+    BufferRanges->setSelection( Selection );
     BufferCursor->gotoEnd();
   }
 
@@ -764,7 +787,7 @@ void KHexEdit::selectAll( bool Select )
 
   if( !OverWrite ) emit cutAvailable( BufferRanges->hasSelection() );
   emit copyAvailable( BufferRanges->hasSelection() );
-  emit selectionChanged();
+  emit selectionChanged( Selection.start(), Selection.end() );
   viewport()->setCursor( isReadOnly() ? arrowCursor : ibeamCursor );
 }
 
@@ -871,29 +894,32 @@ void KHexEdit::insert( const QByteArray &D )
 {
   pauseCursor( true );
 
+  KSection ChangedRange;
+
   if( OverWrite )
   {
     if( BufferRanges->hasSelection() )
     {
       // replacing the selection:
       // we restrict the replacement to the minimum length of selection and input
-      KSection Selection = BufferRanges->selection();
-      Selection.restrictEndTo( Selection.start()+D.size()-1 );
-      int W = DataBuffer->replace( Selection, D.data(), Selection.width() );
-      BufferCursor->gotoCIndex( Selection.start()+W );
-      BufferRanges->addChangedRange( Selection );
+      ChangedRange = BufferRanges->selection();
+      ChangedRange.restrictEndTo( ChangedRange.start()+D.size()-1 );
+      int W = DataBuffer->replace( ChangedRange, D.data(), ChangedRange.width() );
+      BufferCursor->gotoCIndex( ChangedRange.start()+W );
       BufferRanges->removeSelection();
     }
     else
     {
-      // replacing the normal data, at least until the end
-      KSection Section( BufferCursor->realIndex(), D.size(), false );
-      Section.restrictEndTo( BufferLayout->length()-1 );
-      if( Section.isValid() && !BufferCursor->isBehind() )
+      if( !BufferCursor->isBehind() )
       {
-        int W = DataBuffer->replace( Section, D.data(), Section.width() );
-        BufferCursor->gotoNextByte( W );
-        BufferRanges->addChangedRange( Section );
+        // replacing the normal data, at least until the end
+        ChangedRange.setByWidth( BufferCursor->realIndex(), D.size() );
+        ChangedRange.restrictEndTo( BufferLayout->length()-1 );
+        if( ChangedRange.isValid() )
+        {
+          int W = DataBuffer->replace( ChangedRange, D.data(), ChangedRange.width() );
+          BufferCursor->gotoNextByte( W );
+        }
       }
     }
   }
@@ -910,11 +936,11 @@ void KHexEdit::insert( const QByteArray &D )
       if( W > 0 )
       {
         if( Selection.width() == (int)D.size() )
-          BufferRanges->addChangedRange( Selection );
+          ChangedRange = Selection;
         else
         {
           int NewLastIndex = DataBuffer->size() - 1;
-          BufferRanges->addChangedRange( Selection.start(), NewLastIndex>OldLastIndex?NewLastIndex:OldLastIndex );
+          ChangedRange.set( Selection.start(), NewLastIndex>OldLastIndex?NewLastIndex:OldLastIndex );
         }
       }
       BufferRanges->removeSelection();
@@ -932,17 +958,24 @@ void KHexEdit::insert( const QByteArray &D )
           BufferCursor->gotoEnd();
         else
           BufferCursor->gotoNextByte( W );
-        BufferRanges->addChangedRange( KSection(OldIndex,DataBuffer->size()-1) );
+        ChangedRange.set( OldIndex, DataBuffer->size()-1 );
       }
     }
   }
-  repaintChanged();
+
+  bool Changed = ChangedRange.isValid();
+  if( Changed )
+  {
+    BufferRanges->addChangedRange( ChangedRange );
+    repaintChanged();
+  }
   ensureCursorVisible();
 
   unpauseCursor();
 
-  emit bufferChanged();
-  emit selectionChanged();
+  if( Changed ) emit bufferChanged( ChangedRange.start(), ChangedRange.end() );
+  KSection Selection = BufferRanges->selection();
+  emit selectionChanged( Selection.start(), Selection.end() );
 }
 
 
@@ -958,7 +991,7 @@ void KHexEdit::removeSelectedData()
 
   BufferRanges->removeFurtherSelections();
 
-  removeData( Selection );
+  KSection ChangedRange = removeData( Selection );
   BufferRanges->removeSelection();
 
   repaintChanged();
@@ -971,12 +1004,12 @@ void KHexEdit::removeSelectedData()
 
   unpauseCursor();
 
-  emit bufferChanged();
-  emit selectionChanged();
+  if( ChangedRange.isValid() ) emit bufferChanged( ChangedRange.start(), ChangedRange.end() );
+  emit selectionChanged( -1, -1 );
 }
 
 
-void KHexEdit::removeData( KSection Indizes )
+KSection KHexEdit::removeData( KSection Indizes )
 {
 //   if( undoEnabled )
 //   {
@@ -989,11 +1022,13 @@ void KHexEdit::removeData( KSection Indizes )
 //     readFormats( c1, c2, undoRedoInfo.d->text, TRUE );
 //   }
 
-  int OldLastIndex = BufferLayout->length()-1;
+  KSection ChangedRange( Indizes.start(), BufferLayout->length()-1 );
   // do it!
   DataBuffer->remove( Indizes );
   updateLength();
-  BufferRanges->addChangedRange( Indizes.start(), OldLastIndex );
+  BufferRanges->addChangedRange( ChangedRange );
+
+  return ChangedRange;
 }
 
 
@@ -1021,19 +1056,23 @@ void KHexEdit::setCursorPosition( int Index, bool Behind )
     BufferCursor->stepBehind();
 
   BufferRanges->removeSelection();
-  if( BufferRanges->isModified() )
+  bool RangesModifed = BufferRanges->isModified();
+  if( RangesModifed )
   {
     repaintChanged();
 
     viewport()->setCursor( isReadOnly() ? arrowCursor : ibeamCursor );
 
-    if( !OverWrite ) emit cutAvailable( BufferRanges->hasSelection() );
-    emit copyAvailable( BufferRanges->hasSelection() );
-    emit selectionChanged();
   }
   ensureCursorVisible();
-
   unpauseCursor();
+
+  if( RangesModifed )
+  {
+    if( !OverWrite ) emit cutAvailable( BufferRanges->hasSelection() );
+    emit copyAvailable( BufferRanges->hasSelection() );
+    emit selectionChanged( -1, -1 );
+  }
 }
 
 
@@ -1350,13 +1389,6 @@ void KHexEdit::updateColumn( KColumn &Column )
     updateContents( Column.x(), 0, Column.width(), totalHeight() );
 }
 
-void KHexEdit::emitSelectionSignals()
-{
-  if( !OverWrite ) emit cutAvailable( BufferRanges->hasSelection() );
-  emit copyAvailable( BufferRanges->hasSelection() );
-  emit selectionChanged();
-}
-
 
 void KHexEdit::keyPressEvent( QKeyEvent *KeyEvent )
 {
@@ -1673,16 +1705,17 @@ void KHexEdit::contentsMouseReleaseEvent( QMouseEvent *e )
     unpauseCursor();
   }
 
-  emit cursorPositionChanged( BufferCursor->index() );
-
   InDoubleClick = false;
 
   if( BufferRanges->selectionJustStarted() )
     BufferRanges->removeSelection();
 
+  emit cursorPositionChanged( BufferCursor->index() );
+
   if( !OverWrite ) emit cutAvailable( BufferRanges->hasSelection() );
   emit copyAvailable( BufferRanges->hasSelection() );
-  emit selectionChanged();
+  KSection Selection = BufferRanges->selection();
+  emit selectionChanged( Selection.start(), Selection.end() );
 }
 
 
@@ -1857,18 +1890,16 @@ void KHexEdit::contentsDropEvent( QDropEvent *e )
     handleInternalDrag( e );
   else
   {
-   //BufferRanges->removeSelection(); 
-    pasteFromSource( e ); 
+   //BufferRanges->removeSelection();
+    pasteFromSource( e );
   }
-
-  // emit appropriate signals.
-  emit selectionChanged();
-  emit cursorPositionChanged( BufferCursor->index() );
 }
 
 
 void KHexEdit::handleInternalDrag( QDropEvent *e )
 {
+  KSection ChangedRange;
+
   // stop ui
   pauseCursor();
 
@@ -1884,25 +1915,27 @@ void KHexEdit::handleInternalDrag( QDropEvent *e )
     if( NewIndex != Selection.start() )
     {
       BufferCursor->gotoCIndex( NewIndex+Selection.width() );
-      BufferRanges->addChangedRange( KSection(QMIN(InsertIndex,Selection.start()), QMAX(InsertIndex,Selection.end())) );
+      ChangedRange.set( QMIN(InsertIndex,Selection.start()), QMAX(InsertIndex,Selection.end()) );
     }
   }
   // is a copy
   else
   {
-    // get data  
+    // get data
     QByteArray Data;
     if( KBufferDrag::decode(e,Data) && !Data.isEmpty() )
     {
       if( OverWrite )
       {
-        KSection Section( InsertIndex, Data.size(), false );
-        Section.restrictEndTo( BufferLayout->length()-1 );
-        if( Section.isValid() && !BufferCursor->isBehind() )
+        if( !BufferCursor->isBehind() )
         {
-          int NoOfReplaced = DataBuffer->replace( Section, Data.data(), Section.width() );
-          BufferCursor->gotoNextByte( NoOfReplaced );
-          BufferRanges->addChangedRange( Section );
+          ChangedRange.setByWidth( InsertIndex, Data.size() );
+          ChangedRange.restrictEndTo( BufferLayout->length()-1 );
+          if( ChangedRange.isValid() )
+          {
+            int NoOfReplaced = DataBuffer->replace( ChangedRange, Data.data(), ChangedRange.width() );
+            BufferCursor->gotoNextByte( NoOfReplaced );
+          }
         }
       }
       else
@@ -1912,17 +1945,24 @@ void KHexEdit::handleInternalDrag( QDropEvent *e )
         if( NoOfInserted > 0 )
         {
           BufferCursor->gotoCIndex( InsertIndex + NoOfInserted );
-          BufferRanges->addChangedRange( KSection(InsertIndex,DataBuffer->size()-1) );
+          ChangedRange.set( InsertIndex, DataBuffer->size()-1 );
         }
       }
     }
   }
+  BufferRanges->addChangedRange( ChangedRange );
   BufferRanges->removeSelection();
+
   repaintChanged();
   ensureCursorVisible();
 
   // open ui
   unpauseCursor();
+
+  // emit appropriate signals.
+  emit selectionChanged( -1, -1 );
+  if( ChangedRange.isValid() ) emit bufferChanged( ChangedRange.start(), ChangedRange.end() );
+  emit cursorPositionChanged( BufferCursor->index() );
 }
 
 
