@@ -44,7 +44,8 @@ int main( int argc, char **argv )
   KAboutData aboutData( "kjots", I18N_NOOP("KJots"),
     version, description, KAboutData::License_GPL,
     "(c) 1997-2002, Christoph Neerfeld");
-  aboutData.addAuthor("Jaison Lee", I18N_NOOP("Current maintainer"), "lee.jaison@gmail.com");
+  aboutData.addAuthor("Pradeepto K. Bhattacharya", I18N_NOOP("Current maintainer"), "pradeepto@kde.org");
+  aboutData.addAuthor("Jaison Lee", 0, "lee.jaison@gmail.com");
   aboutData.addAuthor("Aaron J. Seigo", 0, "aseigo@kde.org");
   aboutData.addAuthor("Stanislav Kljuhhin", 0, "crz@starman.ee");
   aboutData.addAuthor("Christoph Neerfeld", I18N_NOOP("Original author"), "chris@kde.org");
