@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -84,7 +84,8 @@ public:
 	QString	val_performance[2];
 	bool	do_throttle[2];
 	QString	val_throttle[2];
-	int	low[2];
+        bool    time_based_action_low, time_based_action_critical;
+	int	low[4];
 	int	poll;			// how often to pol
 
 	
