@@ -9,7 +9,7 @@
  *
  * This file contains the implementation of the main laptop battery monitoring daemon
  *
- * $Id: laptop_daemon.cpp 490596 2005-12-22 13:05:45Z scripty $
+ * $Id: laptop_daemon.cpp 663525 2007-05-11 14:51:26Z lunakl $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -72,6 +72,7 @@ laptop_daemon::laptop_daemon(const QCString& obj): KDEDModule(obj)
 	xwidget->hide();
 	kapp->installX11EventFilter(xwidget);
 
+        mLavEnabled = false;
 	backoffTimer = 0;
 	need_wait = 0;
 	saved_brightness = 0;
@@ -249,7 +250,7 @@ void laptop_daemon::restart()
 	    s.power_performance_enabled[0] || s.power_performance_enabled[1] || s.power_throttle_enabled[0] || s.power_throttle_enabled[1]) {
 		power_time = s.power_wait[powered?0:1];
 		timer = 1;
-		autoLock.setLoadAverage(s.lav_enabled[powered?0:1], s.lav_val[powered?0:1]);
+		setLoadAverage(s.lav_enabled[powered?0:1], s.lav_val[powered?0:1]);
 		autoLock.setTimeout(power_time);
 		autoLock.start();
 	} else {
@@ -323,6 +324,10 @@ void laptop_daemon::setBlankSaver(bool blanked)
 
 void laptop_daemon::timerDone()
 {
+	if (mLavEnabled && laptop_portable::get_load_average() >= mLav) {
+            autoLock.postpone(); // will call timerDone() again later
+            return;
+        }
 	int action;
 
 	timer = 0;
@@ -457,16 +462,8 @@ laptop_daemon::x11Event(XEvent *event)
     case ButtonPress:
 	    if (need_wait)
 	        WakeUpAuto();
-            if (!event->xkey.send_event) {
-		    if (need_wait)
-			    WakeUpAuto();
-	            autoLock.keyPressed();
-	    }
 	    break;
 
-    case CreateNotify:
-            autoLock.windowCreated(event->xcreatewindow.window);
-	    break;
     }
     return(0);
 }
@@ -679,7 +676,7 @@ void laptop_daemon::checkBatteryNow()
 		saved_brightness = 0;
        		saved_throttle = 0;
        		saved_performance = 0;
-		autoLock.setLoadAverage(s.lav_enabled[powered?0:1], s.lav_val[powered?0:1]);
+		setLoadAverage(s.lav_enabled[powered?0:1], s.lav_val[powered?0:1]);
 		if (power_time != s.power_wait[powered?0:1]) {
 			power_time = s.power_wait[powered?0:1];
 			autoLock.stop();
