@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -31,8 +31,8 @@ int main(int, char**)
 	checkcrc("./klaptop_acpi_helper", len, crc);
 	printf("#ifndef _CRCRESULT_H_\n");
 	printf("#define _CRCRESULT_H_\n");
-	printf("static unsigned long file_len = 0x%x;\n", len);
-	printf("static unsigned long file_crc = 0x%x;\n", crc);
+	printf("static unsigned long file_len = 0x%lx;\n", len);
+	printf("static unsigned long file_crc = 0x%lx;\n", crc);
 	printf("#endif\n");
 	return(0);
 }
