@@ -1,7 +1,7 @@
 /*
  * portable.cpp
  *
- * $Id: portable.cpp 540996 2006-05-15 09:55:42Z mueller $
+ * $Id: portable.cpp 629304 2007-02-02 09:55:28Z dfaure $
  *
  * Copyright (c) 1999 Paul Campbell <paul@taniwha.com>
  *
@@ -1957,19 +1957,19 @@ bool
 laptop_portable::get_button(LaptopButton l)	// true if a button is pressed
 {
 	if (::has_acpi()) {
-		QString *name=0;
+		QString name;
 		switch (l) {
 		case LidButton:
-			name = &acpi_lid_name;
+			name = acpi_lid_name;
 			break;
 		case PowerButton:
-			name = &acpi_power_name;
+			name = acpi_power_name;
 			break;
 		default:
 			break;
 		}
-		if (name) {
-			QFile f(*name);
+		if (!name.isEmpty()) {
+			QFile f(name);
 			if (f.open(IO_ReadOnly)) {
 				while (!f.atEnd()) {
 					QString l;
