@@ -92,7 +92,7 @@ bool GenericMonitor::retrieveVolume()
 {
 	bool kmix_error = false;
 
-	DCOPReply reply = kmixClient->call("masterVolume");
+	DCOPReply reply = kmixClient->call("absoluteVolume", 0);
 	if (reply.isValid())
 		m_volume = reply;
 	else
@@ -104,7 +104,7 @@ bool GenericMonitor::retrieveVolume()
 		if (kapp->startServiceByDesktopName("kmix")==0) // trying to start kmix
 		{
 			// trying again
-			reply = kmixClient->call("masterVolume");
+			reply = kmixClient->call("absoluteVolume", 0);
 			if (reply.isValid()) 
 			{
 				m_volume = reply;
@@ -122,6 +122,10 @@ bool GenericMonitor::retrieveVolume()
 		
 		return false;
 	} else {
+		reply = kmixClient->call("absoluteVolumeMax", 0);
+		m_maxVolume = reply;
+		reply = kmixClient->call("absoluteVolumeMin", 0);
+		m_minVolume = reply;
 		return true;
 	}
 }
@@ -131,9 +135,7 @@ void GenericMonitor::volumeUp(int step)
 	if (!retrieveVolume())
 		return;
 
-	// FIXME if the mixer doesn't support steps of the specified size it
-	// could get stuck at one position
-	m_volume += step;
+	m_volume += (int)((m_maxVolume - m_minVolume) * step /100) +1;
 	if (m_volume > m_maxVolume)
 		m_volume = m_maxVolume;
 
@@ -145,7 +147,7 @@ void GenericMonitor::volumeDown(int step)
 	if (!retrieveVolume())
 		return;
 
-	m_volume -= step;
+	m_volume -= (int)((m_maxVolume - m_minVolume) * step /100) +1;
 	if (m_volume < m_minVolume)
 		m_volume = m_minVolume;
 							 
@@ -159,11 +161,11 @@ void GenericMonitor::fastVolumeDown() {	volumeDown(10); }
 
 void GenericMonitor::displayVolume()
 {
-	_interface->displayProgress(i18n("Volume"), m_volume);
+	_interface->displayProgress(i18n("Volume"), (int)(m_volume * 100 / (m_maxVolume - m_minVolume)));
 
 	// If we got this far, the DCOP communication with kmix works,
-  // so we don't have to test the result.
-	kmixClient->send("setMasterVolume", m_volume);
+	// so we don't have to test the result.
+	kmixClient->send("setAbsoluteVolume", 0, m_volume);
 
 	// if mute then unmute
 	if (m_mute)
