@@ -11,7 +11,7 @@
          This code may be linked against any version of the Qt toolkit
          from Troll Tech, Norway. $
 
-   $Id: kmilo_kvaio.cpp 299080 2004-03-27 17:56:09Z waba $
+   $Id: kmilo_kvaio.cpp 464898 2005-09-28 14:40:11Z mueller $
 
    * Portions of this code are
    * (C) 2001-2002 Stelian Pop <stelian@popies.net> and
@@ -21,16 +21,18 @@
 
 #include <kgenericfactory.h>
 
+#include "monitor.h"
 #include "kmilo_kvaio.h"
 #include "kvaio.h"
-
-namespace KMilo {
+#include "kmilointerface.h"
 
 KMiloKVaio::KMiloKVaio(QObject *parent, const char *name,
 		       const QStringList& args)
     : Monitor(parent, name, args),
       m_kvaio(0)
 {
+    _poll = false;
+    m_displayType = (Monitor::DisplayType)None ;
 }
 
 
@@ -46,16 +48,15 @@ bool KMiloKVaio::init()
 }
 
 
-Monitor::DisplayType KMiloKVaio::poll() {
-Monitor::DisplayType rc = (Monitor::DisplayType)None;
-return rc;
+KMilo::Monitor::DisplayType KMiloKVaio::poll() {
+//    Monitor::DisplayType rc = (Monitor::DisplayType)None;
+//    return rc;
+    return m_displayType;
 }
 
 
 int KMiloKVaio::progress() const {
-	return 10;
-}
-
+	return m_kvaio->progress();
 }
 
 void KMiloKVaio::reconfigure(KConfig* k)
