@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "ksimcpu.h"
@@ -186,7 +186,10 @@ void CpuView::updateView()
       else if (text.find("%n") != -1)
         cpuDiff = cpuData.nice;
 
-      cpuDiff = cpuDiff * 100 / total;
+      cpuDiff *= 100;
+	  
+	  if ( total > 0 )
+		  cpuDiff /= total;
 
       if (cpuDiff > 100)
         cpuDiff = 100;
@@ -304,8 +307,9 @@ void CpuView::addDisplay()
 {
   CpuList::Iterator it;
   for (it = m_cpus.begin(); it != m_cpus.end(); ++it) {
-    KSim::Chart *chart = addChart();
     KSim::Progress *progress = addLabel();
+    KSim::Chart *chart = addChart();
+    //KSim::Progress *progress = addLabel();
 
     (*it).setDisplay(chart, progress);
   }
