@@ -20,6 +20,7 @@ public:
 
 k_dcop:
     virtual ASYNC openTheme(QString file) = 0;
+    virtual ASYNC openNamedTheme(QString file, QString name, bool is_sub_theme) = 0;
     virtual ASYNC closeTheme(QString name) = 0;
     virtual ASYNC quit() = 0;
     virtual ASYNC hideSystemTray(bool hide) = 0;
@@ -27,6 +28,8 @@ k_dcop:
 
     virtual int themeAdded(QString appId, QString file) = 0;
     virtual ASYNC themeClosed(QString appId, QString file, int instance) = 0;
+    virtual ASYNC themeNotify(QString name, QString text) = 0;
+    virtual ASYNC setIncomingData(QString name, QString obj) = 0;
     virtual bool isMainKaramba() = 0;
 
 };
